Extensible : Basic Calendar

# Basic Calendar Examples

An assortment of basic, standalone CalendarPanels with different configurations. Note that unless otherwise indicated the calendars all share the same underlying data store, so changes in one calendar will update the others.

View the source

## Simplest Example

This is an example of the most basic CalendarPanel configuration with all default options. It does not have multiple calendar support by default (unless you provide a calendar store) and so all events simply use a deafult color.

## Panel Configs

This example shows the CalendarPanel with additional standard Panel configs applied, showing that it can be used just like any other Panel subclass in Ext JS. It also defaults to the week view to show that you can start with whichever view you want.